@@ -3,7 +3,7 @@
 // implied warranty of merchantability or fitness for a particular purpose.
 // See file LICENSE for details and terms of copying.
 
-#import <objectbase.h>
+#import <objectbase/Swarm.h>
 #import "SugarSpace.h"
 #import "SugarAgent.h"
 #import "Shuffler.h"
@@ -12,7 +12,8 @@
 // model. In the simplest case, this is basically a list of agents, a
 // sugarspace world, and various parameters.
 
-@interface ModelSwarm : Swarm {
+@interface ModelSwarm: Swarm
+{
   // Parameters for the model
   int numAgents;
   int alpha;					  // growth rate for sugar
@@ -21,12 +22,12 @@
   int minInitialSugar, maxInitialSugar;
   int deathAgeMin, deathAgeMax;
   int worldXSize, worldYSize;
-  char * datafile;
+  const char *datafile;
 
   // Objects in the list
   id agentList;
-  Shuffler * shuffler;
-  SugarSpace * sugarSpace;
+  Shuffler *shuffler;
+  SugarSpace *sugarSpace;
   id reaperQueue;
 
   // Schedule stuff
@@ -35,17 +36,17 @@
 }
 
 // Methods to handle the agents in the world
--addNewRandomAgent;
--agentBirth: (SugarAgent *) agent;
--agentDeath: (SugarAgent *) agent;
+- addNewRandomAgent;
+- agentBirth: (SugarAgent *)agent;
+- agentDeath: (SugarAgent *)agent;
 
 // Accessor functions
--(SugarSpace *) getSugarSpace;
--getAgentList;
+- (SugarSpace *)getSugarSpace;
+- getAgentList;
 
 // Scheduling methods
--buildObjects;
--buildActions;
--activateIn: (id) swarmContext;
+- buildObjects;
+- buildActions;
+- activateIn: swarmContext;
 
 @end
